[−][src]Struct chrootable_https::Client
A Client to make outgoing HTTP requests.
Uses an specific DNS resolver.
Methods
impl<R: DnsResolver + 'static> Client<R>[src]
pub fn new(resolver: R) -> Client<R>[src]
Create a new client with a specific DNS resolver.
This bypasses /etc/resolv.conf.
pub fn get(&self, url: &str) -> ResponseFuture[src]
Shorthand function to do a GET request with HttpClient::request.
impl Client<Resolver>[src]
pub fn with_system_resolver() -> Result<Client<Resolver>>[src]
Create a new client with the system resolver from /etc/resolv.conf.
pub fn with_socks5(proxy: SocketAddr) -> Client<Resolver>[src]
Create a new client that is locked to a socks5 proxy